export var __esModule: boolean;
export default BinaryStream;
/**
 * A binary stream.
 */
declare class BinaryStream {
    constructor(buffer: any, byteOffset: any, byteLength: any);
    index: number;
    buffer: any;
    uint8array: Uint8Array;
    byteLength: any;
    remaining: any;
    /**
     * Create a subreader of this reader, at its position, with the given byte length.
     */
    substream(byteLength: any): BinaryStream;
    /**
     * Skip a number of bytes.
     */
    skip(bytes: any): void;
    /**
     * Set the reader's index.
     */
    seek(index: any): void;
    /**
     * Read a UTF8 string with the given number of bytes.
     *
     * The entire size will be read, however the string returned is NULL terminated in its memory block.
     *
     * For example, the MDX format has many strings that have a constant maximum size, where any bytes after the string are NULLs.
     * Such strings will be loaded correctly given the maximum size.
     */
    read(bytes: any): string;
    /**
     * Read a UTF8 NULL terminated string.
     */
    readNull(): string;
    /**
     * Read a binary string with the given number of bytes.
     */
    readBinary(bytes: any): string;
    /**
     * Read a 8 bit signed integer.
     */
    readInt8(): number;
    /**
     * Read a 16 bit signed integer.
     */
    readInt16(): number;
    /**
     * Read a 32 bit signed integer.
     */
    readInt32(): number;
    /**
     * Read a 8 bit unsigned integer.
     */
    readUint8(): number;
    /**
     * Read a 16 bit unsigned integer.
     */
    readUint16(): number;
    /**
     * Read a 32 bit unsigned integer.
     */
    readUint32(): number;
    /**
     * Read a 32 bit float.
     */
    readFloat32(): number;
    /**
     * Read a 64 bit float.
     */
    readFloat64(): number;
    /**
     * Read an array of 8 bit signed integers.
     */
    readInt8Array(view: any): any;
    /**
     * Read an array of 16 bit signed integers.
     */
    readInt16Array(view: any): any;
    /**
     * Read an array of 32 bit signed integers.
     */
    readInt32Array(view: any): any;
    /**
     * Read an array of 8 bit unsigned integers.
     */
    readUint8Array(view: any): any;
    /**
     * Read an array of 16 bit unsigned integers.
     */
    readUint16Array(view: any): any;
    /**
     * Read an array of 32 bit unsigned integers.
     */
    readUint32Array(view: any): any;
    /**
     * Read an array of 32 bit floats.
     */
    readFloat32Array(view: any): any;
    /**
     * Read an array of 64 bit floats.
     */
    readFloat64Array(view: any): any;
    /**
     * Write a UTF8 string.
     *
     * Returns the number of bytes that were written,
     */
    write(utf8: any): number;
    /**
     * Write a UTF8 string as a NULL terminated string.
     *
     * Returns the number of bytes that were written, including the terminating NULL.
     */
    writeNull(utf8: any): number;
    /**
     * Write a binary string.
     */
    writeBinary(value: any): void;
    /**
     * Write a 8 bit signed integer.
     */
    writeInt8(value: any): void;
    /**
     * Write a 16 bit signed integer.
     */
    writeInt16(value: any): void;
    /**
     * Write a 32 bit signed integer.
     */
    writeInt32(value: any): void;
    /**
     * Write a 8 bit unsigned integer.
     */
    writeUint8(value: any): void;
    /**
     * Write a 16 bit unsigned integer.
     */
    writeUint16(value: any): void;
    /**
     * Write a 32 bit unsigned integer.
     */
    writeUint32(value: any): void;
    /**
     * Write a 32 bit float.
     */
    writeFloat32(value: any): void;
    /**
     * Write a 64 bit float.
     */
    writeFloat64(value: any): void;
    /**
     * Write an array of 8 bit signed integers.
     */
    writeInt8Array(view: any): void;
    /**
     * Write an array of 16 bit signed integers.
     */
    writeInt16Array(view: any): void;
    /**
     * Write an array of 32 bit signed integers.
     */
    writeInt32Array(view: any): void;
    /**
     * Write an array of 8 bit unsigned integers.
     */
    writeUint8Array(view: any): void;
    /**
     * Write an array of 16 bit unsigned integers.
     */
    writeUint16Array(view: any): void;
    /**
     * Write an array of 32 bit unsigned integers.
     */
    writeUint32Array(view: any): void;
    /**
     * Write an array of 32 bit floats.
     */
    writeFloat32Array(view: any): void;
    /**
     * Write an array of 64 bit floats.
     */
    writeFloat64Array(view: any): void;
}
