export var __esModule: boolean;
export default Model;
/**
 * A Warcraft 3 model.
 * Supports loading from and saving to both the binary MDX and text MDL file formats.
 */
declare class Model {
    /**
     * 800 for Warcraft 3: RoC and TFT.
     * >800 for Warcraft 3: Reforged.
     */
    version: number;
    name: string;
    /**
     * To the best of my knowledge, this should always be left empty.
     */
    animationFile: string;
    extent: extent_1.default;
    /**
     * This is only used by the now-defunct previewer that came with Art Tools.
     */
    blendTime: number;
    sequences: any[];
    globalSequences: any[];
    materials: any[];
    textures: any[];
    textureAnimations: any[];
    geosets: any[];
    geosetAnimations: any[];
    bones: any[];
    lights: any[];
    helpers: any[];
    attachments: any[];
    pivotPoints: any[];
    particleEmitters: any[];
    particleEmitters2: any[];
    /**
     * @since 900
     */
    particleEmittersPopcorn: any[];
    ribbonEmitters: any[];
    cameras: any[];
    eventObjects: any[];
    collisionShapes: any[];
    /**
     * @since 900
     */
    faceEffects: any[];
    /**
     * @since 900
     */
    bindPose: any[];
    /**
     * The MDX format is chunk based, and Warcraft 3 does not mind there being unknown chunks in there.
     * Some 3rd party tools use this to attach metadata to models.
     * When an unknown chunk is encountered, it will be added here.
     * These chunks will be saved when saving as MDX.
     */
    unknownChunks: any[];
    /**
     * Load the model from MDX or MDL.
     * The format is detected automatically.
     */
    load(buffer: any): void;
    /**
     * Load the model from MDX.
     */
    loadMdx(buffer: any): void;
    loadVersionChunk(stream: any): void;
    loadModelChunk(stream: any): void;
    loadStaticObjects(out: any, constructor: any, stream: any, count: any): void;
    loadGlobalSequenceChunk(stream: any, size: any): void;
    loadDynamicObjects(out: any, constructor: any, stream: any, size: any): void;
    loadPivotPointChunk(stream: any, size: any): void;
    loadBindPoseChunk(stream: any, size: any): void;
    /**
     * Save the model as MDX.
     */
    saveMdx(): Uint8Array;
    saveVersionChunk(stream: any): void;
    saveModelChunk(stream: any): void;
    saveStaticObjectChunk(stream: any, name: any, objects: any, size: any): void;
    saveGlobalSequenceChunk(stream: any): void;
    saveDynamicObjectChunk(stream: any, name: any, objects: any): void;
    savePivotPointChunk(stream: any): void;
    saveBindPoseChunk(stream: any): void;
    /**
     * Load the model from MDL.
     */
    loadMdl(buffer: any): void;
    loadVersionBlock(stream: any): void;
    loadModelBlock(stream: any): void;
    loadNumberedObjectBlock(out: any, constructor: any, name: any, stream: any): void;
    loadGlobalSequenceBlock(stream: any): void;
    loadObject(out: any, constructor: any, stream: any): void;
    loadPivotPointBlock(stream: any): void;
    loadBindPoseBlock(stream: any): void;
    /**
     * Save the model as MDL.
     */
    saveMdl(): string;
    saveVersionBlock(stream: any): void;
    saveModelBlock(stream: any): void;
    saveStaticObjectsBlock(stream: any, name: any, objects: any): void;
    saveGlobalSequenceBlock(stream: any): void;
    saveObjects(stream: any, objects: any): void;
    savePivotPointBlock(stream: any): void;
    saveBindPoseBlock(stream: any): void;
    /**
     * Calculate the size of the model as MDX.
     */
    getByteLength(): number;
    getObjectsByteLength(objects: any): number;
    getDynamicObjectsChunkByteLength(objects: any): number;
    getStaticObjectsChunkByteLength(objects: any, size: any): number;
    getBindPoseChunkByteLength(): number;
}
import extent_1 = require("./extent");
