export var __esModule: boolean;
export default War3Map;
/**
 * Warcraft 3 map (W3X and W3M).
 */
declare class War3Map {
    u1: number;
    name: string;
    flags: number;
    maxPlayers: number;
    archive: archive_1.default;
    imports: file_1.default;
    readonly: boolean;
    /**
     * Load an existing map.
     *
     * Note that this clears the map from whatever it had in it before.
     */
    load(buffer: any, readonly?: boolean): void;
    /**
     * Save this map.
     * If the archive is in readonly mode, returns null.
     */
    save(): Uint8Array | null;
    /**
     * A shortcut to the internal archive function.
     */
    getFileNames(): string[];
    /**
     * Gets a list of the file names imported in this map.
     */
    getImportNames(): string[];
    /**
     * Sets the imports file with all of the imports.
     *
     * Does nothing if the archive is in readonly mode.
     */
    setImportsFile(): boolean;
    /**
     * Imports a file to this archive.
     *
     * If the file already exists, its buffer will be set.
     *
     * Files added to the archive but not to the imports list will be deleted by the World Editor automatically.
     * This of course doesn't apply to internal map files.
     *
     * Does nothing if the archive is in readonly mode.
     */
    import(name: any, buffer: any): boolean;
    /**
     * A shortcut to the internal archive function.
     */
    set(name: any, buffer: any): boolean;
    /**
     * A shortcut to the internal archive function.
     */
    get(name: any): import("../mpq/file").default | null;
    /**
     * Get the map's script.
     */
    getScriptFile(): import("../mpq/file").default | null;
    /**
     * A shortcut to the internal archive function.
     */
    has(name: any): boolean;
    /**
     * Deletes a file from the internal archive.
     *
     * Note that if the file is in the imports list, it will be removed from it too.
     *
     * Use this rather than the internal archive's delete.
     */
    delete(name: any): boolean;
    /**
     * A shortcut to the internal archive function.
     */
    rename(name: any, newName: any): boolean;
    /**
     * @throws if an error occurs, or the file does not exist.
     */
    getMapInformation(): file_7.default;
    /**
     * Read the imports file.
     */
    readImports(): void;
    /**
     * Read and parse the trigger file.
     */
    readTriggers(triggerData: any): file_5.default | undefined;
    /**
     * Read and parse the custom text trigger file.
     */
    readCustomTextTriggers(): file_4.default | undefined;
    /**
     * Read and parse the string table file.
     */
    readStringTable(): file_6.default | undefined;
    /**
     * Read and parse all of the modification tables.
     */
    readModifications(): {};
}
import archive_1 = require("../mpq/archive");
import file_1 = require("./imp/file");
import file_7 = require("./w3i/file");
import file_5 = require("./wtg/file");
import file_4 = require("./wct/file");
import file_6 = require("./wts/file");
