export var __esModule: boolean;
export default Camera;
/**
 * A camera.
 */
declare class Camera {
    isPerspective: boolean;
    fov: number;
    aspect: number;
    isOrtho: boolean;
    leftClipPlane: number;
    rightClipPlane: number;
    bottomClipPlane: number;
    topClipPlane: number;
    nearClipPlane: number;
    farClipPlane: number;
    location: gl_matrix_1.vec3;
    rotation: gl_matrix_1.quat;
    inverseRotation: gl_matrix_1.quat;
    /**
     * World -> View.
     */
    viewMatrix: gl_matrix_1.mat4;
    /**
     * View -> Clip.
     */
    projectionMatrix: gl_matrix_1.mat4;
    /**
     * World -> Clip.
     */
    viewProjectionMatrix: gl_matrix_1.mat4;
    /**
     * View -> World.
     */
    inverseViewMatrix: gl_matrix_1.mat4;
    /**
     * Clip -> World.
     */
    inverseViewProjectionMatrix: gl_matrix_1.mat4;
    /**
     * The X axis in camera space.
     */
    directionX: gl_matrix_1.vec3;
    /**
     * The Y axis in camera space.
     */
    directionY: gl_matrix_1.vec3;
    /**
     * The Z axis in camera space.
     */
    directionZ: gl_matrix_1.vec3;
    /**
     * The four corners of a 2x2 rectangle.
     */
    vectors: gl_matrix_1.vec3[];
    /**
     * Same as vectors, however these are all billboarded to the camera.
     */
    billboardedVectors: gl_matrix_1.vec3[];
    /**
     * The camera frustum planes in this order: left, right, top, bottom, near, far.
     */
    planes: gl_matrix_1.vec4[];
    /**
     * Set the camera to perspective projection mode.
     */
    perspective(fov: any, aspect: any, near: any, far: any): void;
    /**
     * Set the camera to orthogonal projection mode.
     */
    ortho(left: any, right: any, bottom: any, top: any, near: any, far: any): void;
    /**
     * Set the camera location in world coordinates.
     */
    setLocation(location: any): void;
    /**
     * Move the camera by the given offset in world coordinates.
     */
    move(offset: any): void;
    /**
     * Set the camera rotation.
     */
    setRotation(rotation: any): void;
    /**
     * Rotate the camera by the given rotation.
     */
    rotate(rotation: any): void;
    /**
     * Look at `to`.
     */
    face(to: any, worldUp: any): void;
    /**
     * Move to `from` and look at `to`.
     */
    moveToAndFace(from: any, to: any, worldUp: any): void;
    /**
     * Reset the location and angles.
     */
    reset(): void;
    /**
     * Recalculate the camera's transformation.
     */
    update(): void;
    /**
     * Given a vector in camera space, return the vector transformed to world space.
     */
    cameraToWorld(out: any, v: any): gl_matrix_1.vec3;
    /**
     * Given a vector in world space, return the vector transformed to camera space.
     */
    worldToCamera(out: any, v: any): gl_matrix_1.vec3;
    /**
     * Given a vector in world space, return the vector transformed to screen space.
     */
    worldToScreen(out: any, v: any, viewport: any): any;
    /**
     * Given a vector in screen space, return a ray from the near plane to the far plane.
     */
    screenToWorldRay(out: any, v: any, viewport: any): any;
}
import gl_matrix_1 = require("gl-matrix");
