export var __esModule: boolean;
export var DebugRenderMode: {};
export default ModelViewer;
/**
 * A model viewer.
 */
declare class ModelViewer extends events_1 {
    constructor(canvas: any, options: any);
    /**
     * All of the loaded resources.
     */
    resources: any[];
    /**
     * A map from urls to their resources.
     *
     * Only used by fetched resources.
     */
    resourceMap: Map<any, any>;
    /**
     * A map from urls to the promises that load them.
     *
     * Only used by fetched resources.
     */
    promiseMap: Map<any, any>;
    /**
     * The viewer's handlers, added with `addHandler()`.
     */
    handlers: Set<any>;
    /**
     * The viewer's scenes, added with `addScene()`.
     */
    scenes: any[];
    /**
     * The current frame.
     */
    frame: number;
    /**
     * The number of visible cells on the current frame.
     */
    visibleCells: number;
    /**
     * The number of visible instances on the current frame.
     */
    visibleInstances: number;
    /**
     * The number of particles being updated on the current frame.
     */
    updatedParticles: number;
    /**
     * A viewer-wide flag.
     *
     * If it is false, not only will audio not run, but in fact audio files won't even be fetched in the first place.
     *
     * If audio is desired, this should be set to true before loading models that use audio.
     *
     * Note that it is preferable to call enableAudio(), which checks for the existence of AudioContext.
     */
    audioEnabled: boolean;
    /**
     * A cache of arbitrary data, shared between all of the handlers.
     */
    sharedCache: Map<any, any>;
    /**
     * Debug rendering mode.
     *
     * How it affects the rendering ultimately depends on the handlers.
     */
    debugRenderMode: any;
    directLoadId: number;
    canvas: any;
    gl: WebGLRenderingContext;
    webgl: gl_1.default;
    buffer: import("./gl/clientbuffer").default;
    /**
     * Enable audio if AudioContext is available.
     */
    enableAudio(): boolean;
    /**
     * Add an handler.
     */
    addHandler(handler: any, ...args: any[]): boolean;
    /**
     * Add a scene.
     */
    addScene(): any;
    /**
     * Remove a scene.
     */
    removeScene(scene: any): boolean;
    /**
     * Removes all of the scenes in the viewer.
     */
    clear(): void;
    /**
     * Given a source and an optional path solver, loads a resource and returns a promise to it.
     */
    load(src: any, pathSolver: any, solverParams: any): Promise<any>;
    detectFormat(src: any): any;
    /**
     * Check whether the given string maps to a resource in the cache.
     */
    has(key: any): boolean;
    /**
     * Get a resource from the cache.
     */
    get(key: any): any;
    /**
     * Load something generic.
     *
     * Unlike load(), this does not use handlers or construct any internal objects.
     *
     * `dataType` can be one of: `"image"`, `"string"`, `"arrayBuffer"`, `"bytes"`, `"blob"`.
     *
     * If `callback` isn't given, the resource's `data` is the fetch data, according to `dataType`.
     *
     * If `callback` is given, the resource's `data` is the value returned by it when called with the fetch data.
     *
     * If `callback` returns a promise, the resource's `data` will be whatever the promise resolved to.
     */
    loadGeneric(fetchUrl: any, dataType: any, callback: any): Promise<any>;
    /**
     * Unload a resource.
     * Note that this only removes the resource from the viewer's cache.
     * If it's being referenced and used e.g. by a scene, it will not be garbage collected.
     */
    unload(resource: any): boolean;
    /**
     * Starts loading a new empty resource, and returns it.
     * This empty resource will block the "idle" event (and thus whenAllLoaded) until it's resolved.
     * This is used when a resource might get loaded in the future, but it is not known what it is yet.
     */
    promise(): () => void;
    checkLoadingStatus(): void;
    /**
     * Wait for all of the resources to load.
     *
     * If a callback is given, it will be called, otherwise, a promise is returned.
     */
    whenAllLoaded(callback: any): Promise<any> | undefined;
    /**
     * Get a blob representing the contents of the viewer's canvas.
     *
     * If a callback is given, it will be called, otherwise, a promise is returned.
     */
    toBlob(callback: any): Promise<any> | undefined;
    /**
     * Update and render a frame.
     */
    updateAndRender(dt?: number): void;
    /**
     * Update all of the scenes, which includes updating their cameras, audio context if one exists, and all of the instances they hold.
     */
    update(dt?: number): void;
    /**
     * Clears the WebGL buffer.
     *
     * Called automatically by updateAndRender().
     *
     * Call this at some point before render() if you need more control.
     */
    startFrame(): void;
    /**
     * Render.
     */
    render(): void;
    /**
     * Clear all of the emitted objects in this viewer.
     */
    clearEmittedObjects(): void;
}
import events_1 = require("events");
import gl_1 = require("./gl/gl");
